@@ -17,7 +17,7 @@ from arcana.core.utils.serialize import (
 )
 from arcana.core.deploy.image import Metapackage, App
 from arcana.core.exceptions import ArcanaBuildError
-from arcana.core.data.set import Dataset
+from arcana.core.data.set.base import Dataset
 from arcana.core.data.store import DataStore
 from arcana.core.utils.misc import extract_file_from_docker_image, DOCKER_HUB
 from .base import cli
@@ -41,7 +41,7 @@ containing multiple specifications
 TARGET is the type of image to build, e.g. arcana.xnat.deploy:XnatApp
 the target should resolve to a class deriviing from arcana.core.deploy.App.
 If it is located under the `arcana.deploy`, then that prefix can be dropped, e.g.
-common:App
+core:App
 """,
 )
 @click.argument("spec_root", type=click.Path(exists=True, path_type=Path))
@@ -251,7 +251,7 @@ def make_app(
         for image_spec in image_specs:
 
             extracted_dir = extract_file_from_docker_image(
-                image_spec.reference, image_spec.SPEC_PATH
+                image_spec.reference, image_spec.IN_DOCKER_SPEC_PATH
             )
             if extracted_dir is None:
                 logger.info(
@@ -263,7 +263,7 @@ def make_app(
                     f"Comparing build spec with that of existing image {image_spec.reference}"
                 )
                 built_spec = image_spec.load(
-                    extracted_dir / Path(image_spec.SPEC_PATH).name
+                    extracted_dir / Path(image_spec.IN_DOCKER_SPEC_PATH).name
                 )
 
                 changelog = image_spec.compare_specs(built_spec, check_version=True)
@@ -597,7 +597,7 @@ def install_license(install_locations, license_name, source_file, logfile, logle
         source_file = Path(source_file.decode("utf-8"))
 
     if not install_locations:
-        install_locations = ["file"]
+        install_locations = ["dirtree"]
 
     for install_loc in install_locations:
         if "//" in install_loc:
