@@ -4,7 +4,6 @@ import re
 import typing as ty
 from pathlib import Path
 import shutil
-from itertools import chain
 import attrs
 import attrs.filters
 from attrs.converters import default_if_none
@@ -23,9 +22,9 @@ from ..tree import DataTree
 from .metadata import DatasetMetadata, metadata_converter
 
 
-if ty.TYPE_CHECKING:
-    from ...deploy.image.components import License
-    from ...data.entry import DataEntry
+if ty.TYPE_CHECKING:  # pragma: no cover
+    from arcana.core.deploy.image.components import License
+    from arcana.core.data.entry import DataEntry
 
 logger = logging.getLogger("arcana")
 
@@ -114,10 +113,6 @@ class Dataset:
         Repository specific args used to control the way the dataset is accessed
     """
 
-    # alternative name used to save datasets that are named "" in cases where "" is
-    # not appropriate
-    EMPTY_NAME = "arcana"
-
     LICENSES_PATH = (
         "LICENSES"  # The resource that project-specifc licenses are expected
     )
@@ -169,9 +164,9 @@ class Dataset:
                 "i.e. contain only numbers, letters and underscores and not start with a "
                 "number"
             )
-        if name == self.EMPTY_NAME:
+        if name == self.store.EMPTY_DATASET_NAME:
             raise ArcanaUsageError(
-                f"'{self.EMPTY_NAME}' is a reserved name for datasets as it is used to "
+                f"'{self.store.EMPTY_DATASET_NAME}' is a reserved name for datasets as it is used to "
                 "in place of the empty dataset name in situations where '' can't be used"
             )
 
@@ -491,10 +486,11 @@ class Dataset:
         Sequence[DataRow]
             The sequence of the data row within the dataset
         """
-        with self.tree:
-            if frequency is None:
-                return chain(*(d.values() for d in self.root.children.values()))
+        if frequency is None:
+            frequency = max(self.space)  # "leaf" nodes of the data tree
+        else:
             frequency = self.parse_frequency(frequency)
+        with self.tree:
             if frequency == self.root_freq:
                 return [self.root]
             rows = self.root.children[frequency].values()
