@@ -24,7 +24,7 @@ DS = ty.TypeVar("DS", bound="DataStore")
 logger = logging.getLogger("arcana")
 
 
-if ty.TYPE_CHECKING:
+if ty.TYPE_CHECKING:  # pragma: no cover
     from ..set import Dataset
     from ..tree import DataTree
     from ..entry import DataEntry
@@ -50,11 +50,22 @@ class ConnectionManager(NestedContext):
 
 @attrs.define
 class DataStore(metaclass=ABCMeta):
-    # """
-    # Abstract base class for all Repository systems, DaRIS, XNAT and
-    # local file system. Sets out the interface that all Repository
-    # classes should implement.
-    # """
+    """
+    Abstract base class for all data store adapters. A data store can be an external
+    data management system, e.g. XNAT, OpenNeuro, Datalad or just a defined structure
+    of how to lay out data within a file-system, e.g. BIDS.
+
+    For a data management system/data structure to be compatible with Arcana, it must
+    meet a number of criteria. In Arcana, a store is assumed to
+
+        * contain multiple projects/datasets addressable by unique IDs.
+        * organise data within each project/dataset in trees
+        * store arbitrary numbers of data "items" (e.g. "file-sets" and fields) within
+          each tree node (including non-leaf nodes) addressable by unique "paths" relative
+          to the node.
+        * allow derivative data to be stored within in separate namespaces for different
+          analyses on the same data
+    """
 
     # name: str = None
     connection: ConnectionManager = attrs.field(
@@ -68,6 +79,9 @@ class DataStore(metaclass=ABCMeta):
     SUBPACKAGE = "data"
     VERSION_KEY = "store-version"
     VERSION = "1.0.0"
+    # alternative name used to save datasets that are named "" in cases where "" is
+    # not appropriate
+    EMPTY_DATASET_NAME = "_"
 
     ####################
     # Abstract methods #
@@ -76,24 +90,35 @@ class DataStore(metaclass=ABCMeta):
     @abstractmethod
     def populate_tree(self, tree: DataTree):
         """
-        Populates the nodes of the data tree with those found in the dataset
+        Populates the nodes of the data tree with those found in the dataset using
+        the ``DataTree.add_leaf`` method for every "leaf" node of the dataset tree.
 
         Parameters
         ----------
         tree : DataTree
-            The tree to populate with nodes via the ``DataTree.add_leaf`` method
+            The tree to populate with nodes
         """
 
     @abstractmethod
     def populate_row(self, row: DataRow):
         """
         Populate a row with all data entries found in the corresponding node in the data
-        store (e.g. files within a directory, scans within an XNAT session).
+        store (e.g. files within a directory, scans within an XNAT session) using the
+        ``DataRow.add_entry`` method. Within a node/row there are assumed to be two types
+        of entries, "primary" entries (e.g. acquired scans) common to all analyses performed
+        on the dataset and "derivative" entries corresponding to intermediate outputs
+        of previously performed analyses. These types should be stored in separate
+        namespaces so there is no chance of a derivative overriding a primary data item.
+
+        The name of the dataset/analysis a derivative was generated by is appended to
+        to a base path, delimited by "@", e.g. "brain_mask@my_analysis". The dataset
+        name is left blank by default, in which case "@" is just appended to the
+        derivative path, i.e. "brain_mask@".
 
         Parameters
         ----------
         row : DataRow
-            The row to populate with entries using the ``DataRow.add_entry`` method
+            The row to populate with entries
         """
 
     @abstractmethod
@@ -176,7 +201,8 @@ class DataStore(metaclass=ABCMeta):
             YAML.
         name: str
             Name for the dataset definition to distinguish it from other
-            definitions for the same directory/project"""
+            definitions for the same directory/project
+        """
 
     @abstractmethod
     def load_dataset_definition(
@@ -233,8 +259,9 @@ class DataStore(metaclass=ABCMeta):
         hierarchy: list[str],
         space: type,
         id_composition: dict[str, str],
+        **kwargs,
     ):
-        """creates a new empty dataset within in the store. Used in test routines and
+        """Creates a new empty dataset within in the store. Used in test routines and
         importing/exporting datasets between stores
 
         Parameters
@@ -250,7 +277,29 @@ class DataStore(metaclass=ABCMeta):
             the hierarchy of the dataset to be created
         space : type(DataSpace)
             the data space of the dataset
+        id_composition : dict[str, str]
+            Not all IDs will appear explicitly within the hierarchy of the data
+            tree, and some will need to be inferred by extracting components of
+            more specific labels.
+
+            For example, given a set of subject IDs that combination of the ID of
+            the group that they belong to and the member ID within that group
+            (i.e. matched test & control would have same member ID)
+
+                CONTROL01, CONTROL02, CONTROL03, ... and TEST01, TEST02, TEST03
+
+            the group ID can be extracted by providing the a list of tuples
+            containing ID to source the inferred IDs from coupled with a regular
+            expression with named groups
+
+                id_composition = {
+                    'subject': r'(?P<group>[A-Z]+)(?P<member>[0-9]+)')
+                }
+        **kwargs
+            implementing methods should take wildcard **kwargs to allow compatibility
+            with future arguments that might be added
         """
+        raise NotImplementedError
 
     @abstractmethod
     def create_entry(self, path: str, datatype: type, row: DataRow) -> DataEntry:
@@ -302,7 +351,7 @@ class DataStore(metaclass=ABCMeta):
     # General API #
     ###############
 
-    def import_dataset(self, id: str, dataset: Dataset, **kwargs):
+    def import_dataset(self, id: str, dataset: Dataset, name="", **kwargs):
         """Import a dataset from another store, transferring metadata and columns
         defined on the original dataset
 
@@ -312,6 +361,8 @@ class DataStore(metaclass=ABCMeta):
             the ID of the dataset within this store
         dataset : Dataset
             the dataset to import
+        name : str
+            the name to save the specification under
         **kwargs:
             keyword arguments passed through to the `create_data_tree` method
         """
@@ -340,13 +391,13 @@ class DataStore(metaclass=ABCMeta):
                 )
         else:
             self.name = name
-        entries = self.load_saved_entries()
+        entries = self.load_saved_configs()
         # connect to store in case it is needed in the asdict method and to
         # test the connection in general before it is saved
         dct = self.asdict()
         with self.connection:
             entries[dct.pop("name")] = dct
-        self.save_entries(entries, config_path=config_path)
+        self.save_configs(entries, config_path=config_path)
 
     def asdict(self, **kwargs):
         return asdict(self, **kwargs)
@@ -380,7 +431,7 @@ class DataStore(metaclass=ABCMeta):
         ArcanaNameError
             If the name is not found in the saved stores
         """
-        entries = cls.load_saved_entries(config_path)
+        entries = cls.load_saved_configs(config_path)
         try:
             entry = entries[name]
         except KeyError:
@@ -405,11 +456,11 @@ class DataStore(metaclass=ABCMeta):
         name
             Name of the configuration to remove
         """
-        entries = cls.load_saved_entries(config_path)
+        entries = cls.load_saved_configs(config_path)
         del entries[name]
-        cls.save_entries(entries)
+        cls.save_configs(entries)
 
-    def define_dataset(self, id, space=None, hierarchy=None, **kwargs):
+    def define_dataset(self, id, space=None, hierarchy=None, **kwargs) -> Dataset:
         """
         Creates a Arcana dataset definition for an existing data in the
         data store.
@@ -428,8 +479,13 @@ class DataStore(metaclass=ABCMeta):
             per-session, per-subject,...) present in the dataset.
         **kwargs:
             Keyword args passed on to the Dataset init method
+
+        Returns
+        -------
+        Dataset
+            the newly defined dataset
         """
-        if not space:
+        if space is None:
             try:
                 space = self.DEFAULT_SPACE
             except AttributeError as e:
@@ -437,7 +493,7 @@ class DataStore(metaclass=ABCMeta):
                     "'space' kwarg must be specified for datasets in "
                     f"{type(self)} stores"
                 ) from e
-        if not hierarchy:
+        if hierarchy is None:
             try:
                 hierarchy = self.DEFAULT_HIERARCHY
             except AttributeError:
@@ -449,7 +505,7 @@ class DataStore(metaclass=ABCMeta):
         dataset = Dataset(id, store=self, space=space, hierarchy=hierarchy, **kwargs)
         return dataset
 
-    def save_dataset(self, dataset: Dataset, name: str = None):
+    def save_dataset(self, dataset: Dataset, name: str = ""):
         """Save metadata in project definition file for future reference
 
         Parameters
@@ -460,14 +516,17 @@ class DataStore(metaclass=ABCMeta):
             the name for the definition to distinguish from other definitions on
             the same data, by default None
         """
+        if name is None:
+            name = ""
+        save_name = name if name else self.EMPTY_DATASET_NAME
         definition = asdict(dataset, omit=["store", "name"])
         definition[self.VERSION_KEY] = self.VERSION
         if name is None:
             name = dataset.name
         with self.connection:
-            self.save_dataset_definition(dataset.id, definition, name=name)
+            self.save_dataset_definition(dataset.id, definition, name=save_name)
 
-    def load_dataset(self, id, name="", **kwargs):
+    def load_dataset(self, id, name: str = "", **kwargs) -> Dataset:
         """Load an existing dataset definition
 
         Parameters
@@ -488,8 +547,11 @@ class DataStore(metaclass=ABCMeta):
         KeyError
             if the dataset is not found
         """
+        if name is None:
+            name = ""
+        saved_name = name if name else self.EMPTY_DATASET_NAME
         with self.connection:
-            dct = self.load_dataset_definition(id, name)
+            dct = self.load_dataset_definition(id, saved_name)
         if dct is None:
             raise KeyError(f"Did not find a dataset '{id}@{name}'")
         store_version = dct.pop(self.VERSION_KEY)
@@ -505,7 +567,7 @@ class DataStore(metaclass=ABCMeta):
         name: str = None,
         id_composition: dict[str, str] = None,
         **kwargs,
-    ):
+    ) -> Dataset:
         """Creates a new dataset with new rows to store data in
 
         Parameters
@@ -584,22 +646,44 @@ class DataStore(metaclass=ABCMeta):
         return cls._singletons
 
     @classmethod
-    def load_saved_entries(cls, config_path: Path = None):
+    def load_saved_configs(cls, config_path: Path = None) -> dict[str, ty.Any]:
+        """Loads the saved data store configurations from the the user's home
+        directory
+
+        Parameters
+        ----------
+        config_path : Path, optional
+            the file-system path to the configuration, by default uses one in ~/.arcana
+
+        Returns
+        -------
+        dict[str, ty.Any]
+            dictionary containing the saved configs
+        """
         if config_path is None:
             config_path = get_config_file_path(cls.CONFIG_NAME)
         if config_path.exists():
             with open(config_path) as f:
-                entries = yaml.load(f, Loader=yaml.Loader)
+                configs = yaml.load(f, Loader=yaml.Loader)
         else:
-            entries = {}
-        return entries
+            configs = {}
+        return configs
 
     @classmethod
-    def save_entries(cls, entries, config_path: Path = None):
+    def save_configs(cls, configs: dict[str, ty.Any], config_path: Path = None):
+        """_summary_
+
+        Parameters
+        ----------
+        configs : dict[str, ty.Any]
+            dictionary containing the configs to save
+        config_path : Path, optional
+            the file-system path to the configuration, by default uses one in ~/.arcana
+        """
         if config_path is None:
             config_path = get_config_file_path(cls.CONFIG_NAME)
         with open(config_path, "w") as f:
-            yaml.dump(entries, f)
+            yaml.dump(configs, f)
 
     ##################
     # Helper methods #
