@@ -19,7 +19,7 @@ from arcana.core.utils.serialize import (
 )
 from arcana.core.utils.misc import show_workflow_errors
 from arcana.core.data.row import DataRow
-from arcana.core.data.set import Dataset
+from arcana.core.data.set.base import Dataset
 from arcana.core.data.store import DataStore
 from arcana.core.data.space import DataSpace
 from arcana.core.exceptions import ArcanaUsageError
@@ -56,7 +56,7 @@ class ContainerCommand:
         back-reference to the image the command is installed in
     """
 
-    STORE_TYPE = "file"
+    STORE_TYPE = "dirtree"
     DATA_SPACE = None
 
     task: pydra.engine.task.TaskBase = attrs.field(
@@ -154,7 +154,6 @@ class ContainerCommand:
         parameter_values: dict[str, ty.Any] = None,
         work_dir: Path = None,
         ids: list[str] = None,
-        single_row: str = None,
         dataset_hierarchy: str = None,
         dataset_name: str = None,
         overwrite: bool = False,
@@ -228,10 +227,6 @@ class ContainerCommand:
             dataset_locator, store_cache_dir, dataset_hierarchy, dataset_name
         )
 
-        if single_row is not None:
-            # Adds a single row to the dataset (i.e. skips a full scan)
-            dataset.add_leaf(single_row.split(","))
-
         # Install required software licenses from store into container
         if self.image is not None:
             dataset.download_licenses(
@@ -286,6 +281,8 @@ class ContainerCommand:
             path, qualifiers = self.extract_qualifiers_from_path(
                 output_values.get(output.name, output.name)
             )
+            if "@" not in path:
+                path = f"{path}@{dataset.name}"  # Add dataset namespace
             converter_args[output.name] = qualifiers.pop("converter", {})
             if qualifiers:
                 raise ArcanaUsageError(
@@ -296,7 +293,7 @@ class ContainerCommand:
                 column = dataset[output.name]
                 if not column.is_sink:
                     raise ArcanaUsageError(
-                        "Output column name '{output.name}' shadows existing source column"
+                        f"Output column name '{output.name}' shadows existing source column"
                     )
                 logger.info(f"Found existing sink column {column}")
             else:
@@ -510,7 +507,7 @@ class ContainerCommand:
                     id, name
                 )  # FIXME: Does this need to be here or this covered by L253??
             except KeyError:
-                dataset = store.new_dataset(
+                dataset = store.define_dataset(
                     id, hierarchy=hierarchy, space=self.data_space
                 )
         return dataset
